#
# spec file for package VecCore
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           VecCore
Version:        0.8.2
Release:        1.1
Summary:        C++ Library for Portable SIMD Vectorization
License:        Apache-2.0
URL:            https://root-project.github.io/veccore
Source:         https://github.com/root-project/veccore/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  cmake(Vc) >= 1.3.3
BuildRequires:  pkgconfig(gtest) >= 1.11.0

%description
VecCore is a simple abstraction layer on top of other vectorization libraries.
It provides an architecture-independent API for expressing vector operations on
data. Code written with this API can then be dispatched to one of several
backends like Vc, UME::SIMD, or a scalar implementation.

%package devel
Summary:        Headers and cmake modules for VecCore

%description devel
VecCore is a simple abstraction layer on top of other vectorization libraries.

This package provides the headers and cmake modules for %{name}.

%prep
%autosetup -p1 -n veccore-%{version}
# make sure to build with system libraries
rm -rf builtins/*

%build
# The SKIP_RPATH fix is needed for Leap 15.2, but doesn't hurt generally
%cmake -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DCMAKE_CXX_STANDARD=14 \
       -DVC:BOOL=ON \
       -DUMESIMD:BOOL=OFF \
       -DUSE_EXTERNAL_GTEST:BOOL=ON \
       -DBUILD_TESTING:BOOL=ON
%cmake_build

%install
%cmake_install

%check
%ctest

%files devel
%license LICENSE
%doc README.md
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/

%changelog
* Sat Dec 28 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.8.2:
  * Adapt to CMake policy CMP0146, FindCUDA.cmake removed (#25)
  * Disable std::simd backend when compiling with libc++ since their implementation is incomplete (#27)
  * Switch to C++17 as baseline C++ standard
  * Require CMake 3.16 or later, mark up to 3.30 as supported
  * Add support for Nvidia HPC Toolkit Compiler, GCC 15, and Clang 19
  * Drop math functions benchark compiled with -ffast-math
  * Fix memory leak in Julia set benchmark
  * Update builtin version of Vc to 1.4.5
  * Update bundled version of GoogleTest to 1.15.2 and Google benchmark to 1.9.0
  * Update scripts to build/test VecCore with CTest
  * Fix various compiler warnings from newer compiler versions
* Thu Apr 25 2024 Atri Bhattacharya <badshah400@gmail.com>
- Pass CMAKE_CXX_STANDARD=14 to cmake to allow building tests
  against gtest >= 1.14.0.
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * Mark all `Mask{Empty,Full}` as `VECCORE_ATT_HOST_DEVICE`
  * Avoid including SIMD headers when compiling with nvcc
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.0:
  * New backend based on GCC 11's implementation of
    std::experimental::simd, which is part of the experimental
    support for data parallel types in C++20.
  * This backend offers the best of both Vc and UME::SIMD,
    as it performs well in most cases, from SSE2 up to AVX512.
- Drop upstream fixed VecCore-support-external-ctest.patch
* Mon Feb 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add VecCore-support-external-ctest.patch: Support using external
  gtest instead of building it in-source; patch sent upstream.
